@@ -4,8 +4,8 @@ from .API import API
 
 
 __title__ = "SIGMATMPY"
-__version__ = "0.0.3"
-__author__ = "YOU WU"
+__version__ = "0.0.4"
+__author__ = "SIGMATM"
 __license__ = "MIT"
 __copyright__ = "Copyright (c) 2021 BFJFunds"
 
